@@ -5,15 +5,10 @@
 #include <QWebEngineNotification>
 
 #include <QWebEngineUrlRequestInterceptor>
-#include <QWebEngineDownloadRequest>
 
 #include "downloadsmanager.h"
 
-class QQuickWebEngineDownloadRequest : public DownloadItem
-{
-};
-
-
+#include <private/qquickwebenginedownloadrequest_p.h>
 
 FieryWebProfile::FieryWebProfile(QObject *parent)
     : QQuickWebEngineProfile{parent}
@@ -29,14 +24,12 @@ QWebEngineUrlRequestInterceptor *FieryWebProfile::urlInterceptor() const
     return m_urlInterceptor;
 }
 
-void FieryWebProfile::handleDownload(QQuickWebEngineDownloadRequest *downloadItem)
+void FieryWebProfile::handleDownload(DownloadItem *downloadItem)
 {
-        DownloadItem *download = qobject_cast<DownloadItem *>(downloadItem);
-
     qDebug() << "GOT TO DOWNLOAD HANDLE" << downloadItem->url();
 
-    download->accept();
-    download->pause();
+    downloadItem->accept();
+    downloadItem->pause();
 
     DownloadsManager::instance().add(downloadItem);
 }
